## TODO

* Python plotting

* Sphinx docstrings

* Base tutorial

* Adding interfaces to C code, sync C code across R-devel & Python-devel

* Unit tests

* Import test datasetes in json format
   ** markers
   ** enrichment datasets
   ** TF
